==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/sl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Zasebnost",
    "-" : "–",
    "Remove external admin" : "Odstrani zunanjega skrbnika",
    "Add external admin" : "Dodaj zunanjega skrbnika",
    "This server is using full-disk-encryption." : "Strežnik uporablja celostno diskovnom šifriranje.",
    "Your files are not protected by encryption." : "Datoteke niso zaščitene s šifriranjem.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Datoteke so šifrirane prek {linkopen}strežniškega šifriranja ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Strežnik je zaščiten s celostnim diskovnim šifriranjem.",
    "Your data is located in: " : "Podatki so na:",
    "The admin hasn't selected the location of the server yet." : "Skrbnik še ni določil mesta strežnika.",
    "Change data location" : "Spremeni mesto podatkov",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Združeni Arabski Emirati",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigva in Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanija",
    "Armenia" : "Armenija",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentina",
    "American Samoa" : "Ameriška Samoa",
    "Austria" : "Avstrija",
    "Australia" : "Australija",
    "Aruba" : "Aruba",
    "Åland Islands" : "Otočje Åland",
    "Azerbaijan" : "Azerbajdžan",
    "Bosnia and Herzegovina" : "Bosna in Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladeš",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bolgarija",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunej",
    "Bolivia" : "Bolivija",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius in Saba",
    "Brazil" : "Brazilija",
    "Bahamas" : "Bahami",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Otok Bouvet",
    "Botswana" : "Botsvana",
    "Belarus" : "Belorusija",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosovi otoki (Keeling)",
    "Democratic Republic of the Congo" : "Demokratična republika Kongo",
    "Central African Republic" : "Centralno Afriška Republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švica",
    "Cote d'Ivoire" : "Slonokoščeni otoki",
    "Cook Islands" : "Cookovi otoki",
    "Chile" : "Čile",
    "Cameroon" : "Kamerun",
    "China" : "Kitajska",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Božični otoki",
    "Cyprus" : "Ciper",
    "Czech" : "Češčina",
    "Germany" : "Nemčija",
    "Djibouti" : "Džibuti",
    "Denmark" : "Danska",
    "Dominican Republic" : "Dominikanska republika",
    "Algeria" : "Alžirija",
    "Ecuador" : "Ekvador",
    "Estonia" : "Estonija",
    "Egypt" : "Egipt",
    "West Sahara" : "Severna Sahara",
    "Eritrea" : "Eritreja",
    "Spain" : "Španija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Finska",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falklandsko otočje",
    "Faroe Islands" : "Ferski otoki",
    "France" : "Francija",
    "Gabon" : "Gabon",
    "United Kingdom" : "Združeno kraljestvo",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzija",
    "French Guiana" : "Francoska Gvajana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenlandija",
    "Gambia" : "Gambija",
    "Guinea" : "Gvineja",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvatorialna Gvineja",
    "Greece" : "Grčija",
    "South Georgia and the South Sandwich Islands" : "Južna Georgija in Južni Sandwichevi otoki",
    "Guatemala" : "Gvatemala",
    "Guam" : "Gvam",
    "Guinea-Bissau" : "Gvineja-Bissau",
    "Guyana" : "Gvajana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Otoka Heard in McDonald",
    "Croatia" : "Hrvaška",
    "Haiti" : "Haiti",
    "Hungary" : "Madžarska",
    "Indonesia" : "Indonezija",
    "Ireland" : "Irska",
    "Israel" : "Izrael",
    "Isle of Man" : "Otok Man",
    "India" : "Indija",
    "British Indian Ocean Territory" : "Britanski teritorij v Indijskem oceanu",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islandija",
    "Italy" : "Italija",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordanija",
    "Japan" : "Japonska",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Saint Kitts and Nevis" : "Sveti Krištof in Nevis",
    "North Korea" : "Severna Koreja",
    "South Korea" : "Južna Koreja",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmansko otočje",
    "Kazakhstan" : "Kazahstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Sveta Lucija",
    "Liechtenstein" : "Lihtenštajn",
    "Sri Lanka" : "Šrilanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Litva",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova" : "Moldavija",
    "Montenegro" : "Črna Gora",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Maršalovi otoki",
    "Macedonia" : "Makedonija",
    "Mali" : "Mali",
    "Myanmar" : "Mjanmar",
    "Mongolia" : "Mongolija",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Severni Marijanski otoki",
    "Mauritania" : "Mavretanija",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mavricijus",
    "Maldives" : "Maldivi",
    "Malawi" : "Malavi",
    "Mexico" : "Mehika",
    "Malaysia" : "Malezija",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibija",
    "New Caledonia" : "Nova Kaledonija",
    "Niger" : "Niger",
    "Norfolk Island" : "Otok Norfolk",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nizozemska",
    "Norway" : "Norveška",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nova Zelandija",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francoska polinezija",
    "Papua New Guinea" : "Papua Nova Gvineja",
    "Philippines" : "Filipini",
    "Pakistan" : "Pakistan",
    "Poland" : "Poljska",
    "Saint Pierre and Miquelon" : "Saint Pierre in Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Portoriko",
    "Portugal" : "Portugalska",
    "Palau" : "Palau",
    "Paraguay" : "Paragvaj",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Romunija",
    "Serbia" : "Srbija",
    "Russia" : "Rusija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Savdova Arabija",
    "Solomon Islands" : "Solomonovi otoki",
    "Seychelles" : "Sejšeli",
    "Sudan" : "Sudan",
    "Sweden" : "Švedska",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sveta Helena, Ascension in Tristan da Cunha",
    "Slovenia" : "Slovenija",
    "Svalbard and Jan Mayen" : "Svalbard in Jan Mayen",
    "Slovakia" : "Slovaška",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalija",
    "Suriname" : "Surinam",
    "South Sudan" : "Južni Sudan",
    "Sao Tome and Principe" : "Sao Tome in Principe",
    "El Salvador" : "El Salvador",
    "Syria" : "Sirija",
    "Swaziland" : "Svaziland",
    "Turks and Caicos Islands" : "Otoki Turks in Caicos",
    "Chad" : "Čad",
    "Fr. S. Antarctic Lands" : "Francoska južna in antarktična ozemlja",
    "Togo" : "Togo",
    "Thailand" : "Tajska",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunizija",
    "Tonga" : "Tonga",
    "Turkey" : "Turčija",
    "Trinidad and Tobago" : "Trinidad in Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Tajvan",
    "Tanzania" : "Tanzanija",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Ameriški mali oddaljeni otoki",
    "United States" : "Združene države Amerike",
    "Uruguay" : "Urugvaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Sveti sedež",
    "Saint Vincent and the Grenadines" : "Sveti Vincencij in Grenadine",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Deviški otoki (Britanski)",
    "Virgin Islands (U.S.)" : "Deviški otoki (ZDA)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis in Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Južna Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabve",
    "Your Nextcloud account" : "Vaš račun Nextcloud",
    "User Data Manifesto 2.0" : "Uporabniški podatkovni manifest 2.0",
    "Control" : "Nadzor",
    "over user data access" : "nad dostopom do osebnih podatkov",
    "Knowledge" : "Znanje",
    "Freedom" : "Svoboda",
    "to choose a platform" : "izbire delovnega okolja",
    "Learn more ↗" : "Več o tem ↗",
    "Where is your data?" : "Kje so vaši podatki?",
    "Who has access to your data?" : "Kdo ima dostop do vaših podatkov?",
    "Administrators" : "Skrbniki",
    "People you shared with" : "Osebe, ki jim omogočate souporabo",
    "Privacy policy" : "Pravila zasebnosti",
    "Read the privacy policy." : "Preberite pravila zasebnosti",
    "Encryption" : "Šifriranje",
    "Please select a country" : "Izbor države",
    "Bosnia and Herzegowina" : "Bosna in Hercegovina"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/sl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Zasebnost",
    "-" : "–",
    "Remove external admin" : "Odstrani zunanjega skrbnika",
    "Add external admin" : "Dodaj zunanjega skrbnika",
    "Name of external admin" : "Ime zunanjega skrbnika",
    "This server is using full-disk-encryption." : "Strežnik uporablja celostno diskovnom šifriranje.",
    "Your files are not protected by encryption." : "Datoteke niso zaščitene s šifriranjem.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Datoteke so šifrirane prek {linkopen}strežniškega šifriranja ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Strežnik je zaščiten s celostnim diskovnim šifriranjem.",
    "Your data is located in: " : "Podatki so na:",
    "The admin hasn't selected the location of the server yet." : "Skrbnik še ni določil mesta strežnika.",
    "Change data location" : "Spremeni mesto podatkov",
    "Please select a region" : "Izbor regije",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Združeni Arabski Emirati",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigva in Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanija",
    "Armenia" : "Armenija",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentina",
    "American Samoa" : "Ameriška Samoa",
    "Austria" : "Avstrija",
    "Australia" : "Australija",
    "Aruba" : "Aruba",
    "Åland Islands" : "Otočje Åland",
    "Azerbaijan" : "Azerbajdžan",
    "Bosnia and Herzegovina" : "Bosna in Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladeš",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bolgarija",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunej",
    "Bolivia" : "Bolivija",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius in Saba",
    "Brazil" : "Brazilija",
    "Bahamas" : "Bahami",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Otok Bouvet",
    "Botswana" : "Botsvana",
    "Belarus" : "Belorusija",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosovi otoki (Keeling)",
    "Democratic Republic of the Congo" : "Demokratična republika Kongo",
    "Central African Republic" : "Centralno Afriška Republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švica",
    "Cote d'Ivoire" : "Slonokoščeni otoki",
    "Cook Islands" : "Cookovi otoki",
    "Chile" : "Čile",
    "Cameroon" : "Kamerun",
    "China" : "Kitajska",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Božični otoki",
    "Cyprus" : "Ciper",
    "Czech" : "Češčina",
    "Germany" : "Nemčija",
    "Djibouti" : "Džibuti",
    "Denmark" : "Danska",
    "Dominican Republic" : "Dominikanska republika",
    "Algeria" : "Alžirija",
    "Ecuador" : "Ekvador",
    "Estonia" : "Estonija",
    "Egypt" : "Egipt",
    "West Sahara" : "Severna Sahara",
    "Eritrea" : "Eritreja",
    "Spain" : "Španija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Finska",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falklandsko otočje",
    "Micronesia" : "Mikronezija",
    "Faroe Islands" : "Ferski otoki",
    "France" : "Francija",
    "Gabon" : "Gabon",
    "United Kingdom" : "Združeno kraljestvo",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzija",
    "French Guiana" : "Francoska Gvajana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenlandija",
    "Gambia" : "Gambija",
    "Guinea" : "Gvineja",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvatorialna Gvineja",
    "Greece" : "Grčija",
    "South Georgia and the South Sandwich Islands" : "Južna Georgija in Južni Sandwichevi otoki",
    "Guatemala" : "Gvatemala",
    "Guam" : "Gvam",
    "Guinea-Bissau" : "Gvineja-Bissau",
    "Guyana" : "Gvajana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Otoka Heard in McDonald",
    "Croatia" : "Hrvaška",
    "Haiti" : "Haiti",
    "Hungary" : "Madžarska",
    "Indonesia" : "Indonezija",
    "Ireland" : "Irska",
    "Israel" : "Izrael",
    "Isle of Man" : "Otok Man",
    "India" : "Indija",
    "British Indian Ocean Territory" : "Britanski teritorij v Indijskem oceanu",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islandija",
    "Italy" : "Italija",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordanija",
    "Japan" : "Japonska",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comores" : "Komori",
    "Saint Kitts and Nevis" : "Sveti Krištof in Nevis",
    "North Korea" : "Severna Koreja",
    "South Korea" : "Južna Koreja",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmansko otočje",
    "Kazakhstan" : "Kazahstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Sveta Lucija",
    "Liechtenstein" : "Lihtenštajn",
    "Sri Lanka" : "Šrilanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Litva",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova" : "Moldavija",
    "Montenegro" : "Črna Gora",
    "Saint Martin" : "Sveti Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Maršalovi otoki",
    "Macedonia" : "Makedonija",
    "Mali" : "Mali",
    "Myanmar" : "Mjanmar",
    "Mongolia" : "Mongolija",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Severni Marijanski otoki",
    "Mauritania" : "Mavretanija",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mavricijus",
    "Maldives" : "Maldivi",
    "Malawi" : "Malavi",
    "Mexico" : "Mehika",
    "Malaysia" : "Malezija",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibija",
    "New Caledonia" : "Nova Kaledonija",
    "Niger" : "Niger",
    "Norfolk Island" : "Otok Norfolk",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nizozemska",
    "Norway" : "Norveška",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nova Zelandija",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francoska polinezija",
    "Papua New Guinea" : "Papua Nova Gvineja",
    "Philippines" : "Filipini",
    "Pakistan" : "Pakistan",
    "Poland" : "Poljska",
    "Saint Pierre and Miquelon" : "Saint Pierre in Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Portoriko",
    "Palestine" : "Palestina",
    "Portugal" : "Portugalska",
    "Palau" : "Palau",
    "Paraguay" : "Paragvaj",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Romunija",
    "Serbia" : "Srbija",
    "Russia" : "Rusija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Savdova Arabija",
    "Solomon Islands" : "Solomonovi otoki",
    "Seychelles" : "Sejšeli",
    "Sudan" : "Sudan",
    "Sweden" : "Švedska",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sveta Helena, Ascension in Tristan da Cunha",
    "Slovenia" : "Slovenija",
    "Svalbard and Jan Mayen" : "Svalbard in Jan Mayen",
    "Slovakia" : "Slovaška",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalija",
    "Suriname" : "Surinam",
    "South Sudan" : "Južni Sudan",
    "Sao Tome and Principe" : "Sao Tome in Principe",
    "El Salvador" : "El Salvador",
    "Syria" : "Sirija",
    "Swaziland" : "Svaziland",
    "Turks and Caicos Islands" : "Otoki Turks in Caicos",
    "Chad" : "Čad",
    "Fr. S. Antarctic Lands" : "Francoska južna in antarktična ozemlja",
    "Togo" : "Togo",
    "Thailand" : "Tajska",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunizija",
    "Tonga" : "Tonga",
    "Turkey" : "Turčija",
    "Trinidad and Tobago" : "Trinidad in Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Tajvan",
    "Tanzania" : "Tanzanija",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Ameriški mali oddaljeni otoki",
    "United States" : "Združene države Amerike",
    "Uruguay" : "Urugvaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Sveti sedež",
    "Saint Vincent and the Grenadines" : "Sveti Vincencij in Grenadine",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Deviški otoki (Britanski)",
    "Virgin Islands (U.S.)" : "Deviški otoki (ZDA)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis in Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Južna Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabve",
    "Your Nextcloud account" : "Vaš račun Nextcloud",
    "User Data Manifesto 2.0" : "Uporabniški podatkovni manifest 2.0",
    "Control" : "Nadzor",
    "over user data access" : "nad dostopom do osebnih podatkov",
    "Knowledge" : "Znanje",
    "Freedom" : "Svoboda",
    "to choose a platform" : "izbire delovnega okolja",
    "Learn more ↗" : "Več o tem ↗",
    "Where is your data?" : "Kje so vaši podatki?",
    "Who has access to your data?" : "Kdo ima dostop do vaših podatkov?",
    "Administrators" : "Skrbniki",
    "People you shared with" : "Osebe, ki jim omogočate souporabo",
    "Privacy policy" : "Pravila zasebnosti",
    "Read the privacy policy." : "Preberite pravila zasebnosti",
    "Encryption" : "Šifriranje",
    "Please select a country" : "Izbor države",
    "Bosnia and Herzegowina" : "Bosna in Hercegovina"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
